@@ -6,13 +6,8 @@ with 'Object::Remote::Role::Connector::PerlInterpreter';
 
 no warnings 'once';
 
-BEGIN {  }
-
 push @Object::Remote::Connection::Guess, sub {
-  if (($_[0]||'') eq '-') {
-      shift(@_);
-      __PACKAGE__->new(@_);
-  }
+  if (($_[0]||'') eq '-') { __PACKAGE__->new->connect }
 };
 
 1;
